image_button(...) docs.
Params
sizepath to a function that returns the size of the image.
Optional params
backgroundpath to a function that returns the background color to be used.tintpath to a function that returns a color to tint the image with.frame_paddingani32.uv0path to a function that returns the first uv coordinate to be used. The default value is[0.0, 0.0].uv0path to a function that returns the second uv coordinate. The default value is[1.0, 1.0].